==> deepin-camera_1.3.10.orig.tar.xz: deepin-camera-1.3.10/src/translations/deepin-camera_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video çəkilişi gedir. Pəncərə bağlansın?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Qovluğu açın</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotoşəkil</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Kameraları dəyişin</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bağlayın</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopyalayın</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Qovluğu açın</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Çap edin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Bu qovluqla işləmək üçün icazəniz yoxdur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bağlamaq</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Keçərsiz qovluq</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Qovluğu açın</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Əsas</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Fayl yeri</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Çəkin</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Seriya çəkim rejimi</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Avtomatik çəkim gecikməsi</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Çıxış formatı</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ədəd</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ədəd</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera, PC kameranızdan və ya veb-kameranızı istifadə edərək bir şəkil və video çəkmə yardımçıdır.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fayl saxlanılmadı</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Burada saxlanılsın:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Təsvir imkanları ayarları</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Təsvir imkanları:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotolar:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videolar:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Səs effektləri</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Güzgü rejimi</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Fləş işıq</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Çəkimi saxlamaq</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyalayın</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Açın</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Çap etmək</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Ekran qısayolları</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Şəkil çəkimini saxlamaq</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekst menyu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Şəkil çəkin</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video çəkilişi</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Şəkil çəkimini saxlamaq</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Canlı</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>İsti</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Soyuq</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Boz</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Ağ-Qara</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Fləş işıq</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Açıq</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Bağlı</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Çəlikənin kecikməsi</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Süzgəclər</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspozisiya</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Veb-kamera yoxdur</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Vebkamera istifadə olunur</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Çəkimi saxlamaq</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.4.9.orig.tar.xz: deepin-camera-1.4.9/src/translations/deepin-camera_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="az" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video çəkilişi gedir. Pəncərə bağlansın?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Qovluğu açın</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotoşəkil</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Kameraları dəyişin</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bağlayın</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopyalayın</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Qovluğu açın</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Çap edin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Bu qovluqla işləmək üçün icazəniz yoxdur</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Bağlamaq</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Keçərsiz qovluq</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Qovluğu açın</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Əsas</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Fayl yeri</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Çəkin</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Seriya çəkim rejimi</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Avtomatik çəkim gecikməsi</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Çıxış formatı</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ədəd</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ədəd</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera, PC kameranızdan və ya veb-kameranızı istifadə edərək bir şəkil və video çəkmə yardımçıdır.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Fayl saxlanılmadı</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Burada saxlanılsın:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Təsvir imkanları ayarları</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Təsvir imkanları:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotolar:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videolar:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Səs effektləri</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Güzgü rejimi</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Fləş işıq</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Tor xətləri</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1*1 xətlər</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2*2 xətlər</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Çəkimi saxlamaq</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyalayın</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Açın</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Çap etmək</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Ekran qısayolları</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Şəkil çəkimini saxlamaq</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontekst menyu</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Şəkil çəkin</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video çəkilişi</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Şəkil çəkimini saxlamaq</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Canlı</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>İsti</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Soyuq</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Boz</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Ağ-Qara</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Fləş işıq</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Açıq</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Bağlı</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Çəlikənin kecikməsi</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Süzgəclər</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Ekspozisiya</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Veb-kamera yoxdur</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Vebkamera istifadə olunur</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Çəkimi saxlamaq</translation>
    </message>
</context>
</TS>
